@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-error-viewer-extension.c,v 1.16 2004/09/09 22:05:53 adamh Exp $
+ *  $Id: ephy-error-viewer-extension.c,v 1.16.2.2 2004/09/26 16:22:39 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -43,6 +43,8 @@
 
 #include <glib/gi18n-lib.h>
 
+#include <string.h>
+
 #ifdef HAVE_OPENSP
 #include "sgml-validator.h"
 #endif /* HAVE_OPENSP */
@@ -443,6 +445,7 @@ impl_detach_window (EphyExtension *extension,
 	WindowData *data;
 #ifdef HAVE_OPENSP
 	GtkWidget *notebook;
+	GList *tabs, *l;
 #endif /* HAVE_OPENSP */
 
 	/* Remove UI */
@@ -466,6 +469,13 @@ impl_detach_window (EphyExtension *extension,
 		(notebook, G_CALLBACK (tab_removed_cb), window);
 	g_signal_handlers_disconnect_by_func
 		(notebook, G_CALLBACK (switch_page_cb), window);
+
+	tabs = ephy_window_get_tabs (window);
+	for (l = tabs; l != NULL; l = l->next)
+	{
+		tab_removed_cb (notebook, (EphyTab *) l->data, window);
+	}
+	g_list_free (tabs);
 #endif /* HAVE_OPENSP */
 }
 
